@@ -162,9 +162,9 @@ public:
 	float value() const
 		{ return m_value; }
 	float *value_ptr()
-		{ tick(); return &m_value; }
+		{ tick(1); return &m_value; }
 
-	virtual float tick(uint32_t /*nstep*/ = 1)
+	virtual float tick(uint32_t /*nstep*/)
 	{
 		if (m_port && ::fabsf(*m_port - m_vport) > 0.001f)
 			set_value(*m_port);
@@ -201,7 +201,7 @@ public:
 		samplv1_port::set_value(value);
 	}
 
-	float tick(uint32_t nstep = NSTEP)
+	float tick(uint32_t nstep)
 	{
 		if (m_nstep == 0)
 			return samplv1_port::tick(nstep);
@@ -920,11 +920,11 @@ samplv1_impl::~samplv1_impl (void)
 
 	delete [] m_voices;
 
-	// deallocate channels
-	setChannels(0);
-
 	// deallocate local buffers
 	alloc_sfxs(0);
+
+	// deallocate channels
+	setChannels(0);
 }
 
 
