@@ -32,11 +32,28 @@
 #include "lv2/lv2plug.in/ns/ext/atom/util.h"
 
 #include "lv2/lv2plug.in/ns/ext/state/state.h"
-#include "lv2/lv2plug.in/ns/ext/patch/patch.h"
 
 #include "lv2/lv2plug.in/ns/ext/options/options.h"
 #include "lv2/lv2plug.in/ns/ext/buf-size/buf-size.h"
 
+#ifdef CONFIG_LV2_PATCH
+#include "lv2/lv2plug.in/ns/ext/patch/patch.h"
+#endif
+
+#ifndef CONFIG_LV2_ATOM_FORGE_OBJECT
+#define lv2_atom_forge_object(forge, frame, id, otype) \
+		lv2_atom_forge_blank(forge, frame, id, otype)
+#endif
+
+#ifndef CONFIG_LV2_ATOM_FORGE_KEY
+#define lv2_atom_forge_key(forge, key) \
+		lv2_atom_forge_property_head(forge, key, 0)
+#endif
+
+#ifndef LV2_STATE__StateChanged
+#define LV2_STATE__StateChanged LV2_STATE_PREFIX "StateChanged"
+#endif
+
 #include <stdlib.h>
 #include <stdlib.h>
 #include <math.h>
@@ -57,12 +74,13 @@ samplv1_lv2::samplv1_lv2 (
 	double sample_rate, const LV2_Feature *const *host_features )
 	: samplv1(2, float(sample_rate))
 {
+	::memset(&m_urids, 0, sizeof(m_urids));
+
 	m_urid_map = NULL;
 	m_atom_in  = NULL;
 	m_atom_out = NULL;
 	m_schedule = NULL;
-
-	m_ndelta = 0;
+	m_ndelta   = 0;
 
 	const LV2_Options_Option *host_options = NULL;
 
@@ -105,6 +123,9 @@ samplv1_lv2::samplv1_lv2 (
 				m_urids.bufsz_nominalBlockLength = m_urid_map->map(
 					m_urid_map->handle, LV2_BUF_SIZE__nominalBlockLength);
 			#endif
+				m_urids.state_StateChanged = m_urid_map->map(
+					m_urid_map->handle, LV2_STATE__StateChanged);
+			#ifdef CONFIG_LV2_PATCH
 				m_urids.patch_Get = m_urid_map->map(
  					m_urid_map->handle, LV2_PATCH__Get);
 				m_urids.patch_Set = m_urid_map->map(
@@ -117,6 +138,7 @@ samplv1_lv2::samplv1_lv2 (
  					m_urid_map->handle, LV2_PATCH__property);
 				m_urids.patch_value = m_urid_map->map(
  					m_urid_map->handle, LV2_PATCH__value);
+			#endif
 			}
 		}
 		else
@@ -250,6 +272,7 @@ void samplv1_lv2::run ( uint32_t nframes )
 							samplv1::setTempo(host_bpm);
 					}
 				}
+			#ifdef CONFIG_LV2_PATCH
 				else 
 				if (object->body.otype == m_urids.patch_Set) {
 					// set property value
@@ -303,6 +326,7 @@ void samplv1_lv2::run ( uint32_t nframes )
 					// put property values (probably to UI)
 					patch_put(ndelta);
 				}
+			#endif	// CONFIG_LV2_PATCH
 			}
 		}
 		// remember last time for worker response
@@ -469,7 +493,7 @@ static LV2_State_Status samplv1_lv2_state_restore ( LV2_Handle instance,
 	uint32_t loop_start = 0;
 	uint32_t loop_end   = 0;
 
-	uint32_t int_type = pPlugin->urid_map(LV2_ATOM__Int);
+	const uint32_t int_type = pPlugin->urid_map(LV2_ATOM__Int);
 	if (int_type) {
 		key = pPlugin->urid_map(SAMPLV1_LV2_PREFIX "GEN1_LOOP_START");
 		if (key) {
@@ -545,6 +569,19 @@ void samplv1_lv2::select_program ( uint32_t bank, uint32_t program )
 #endif	// CONFIG_LV2_PROGRAMS
 
 
+void samplv1_lv2::updatePreset ( bool /*bDirty*/ )
+{
+	if (m_schedule /*&& bDirty*/) {
+		samplv1_lv2_worker_message mesg;
+		mesg.atom.type = m_urids.state_StateChanged;
+		mesg.atom.size = 0; // nothing else matters.
+		mesg.sample_path = NULL;
+		m_schedule->schedule_work(
+			m_schedule->handle, sizeof(mesg), &mesg);
+	}
+}
+
+
 void samplv1_lv2::updateSample (void)
 {
 	if (m_schedule) {
@@ -558,6 +595,58 @@ void samplv1_lv2::updateSample (void)
 }
 
 
+bool samplv1_lv2::worker_work ( const void *data, uint32_t /*size*/ )
+{
+	const samplv1_lv2_worker_message *mesg
+		= (const samplv1_lv2_worker_message *) data;
+
+	if (mesg->atom.type == m_urids.state_StateChanged)
+		return true;
+	else
+	if (mesg->atom.type == m_urids.gen1_update)
+		return true;
+	else
+	if (mesg->atom.type == m_urids.gen1_sample) {
+		samplv1::setSampleFile(mesg->sample_path);
+		return true;
+	}
+
+	return false;
+}
+
+
+bool samplv1_lv2::worker_response ( const void *data, uint32_t /*size*/ )
+{
+	const samplv1_lv2_worker_message *mesg
+		= (const samplv1_lv2_worker_message *) data;
+	if (mesg->atom.type == m_urids.state_StateChanged)
+		return state_changed();
+
+	// update all properties, and eventually, any observers...
+	samplv1_sched::sync_notify(this, samplv1_sched::Sample, 0);
+
+#ifdef CONFIG_LV2_PATCH
+	return patch_put(m_ndelta);
+#else
+	return true;
+#endif
+}
+
+
+bool samplv1_lv2::state_changed (void)
+{
+	lv2_atom_forge_frame_time(&m_forge, m_ndelta);
+
+	LV2_Atom_Forge_Frame frame;
+	lv2_atom_forge_object(&m_forge, &frame, 0, m_urids.state_StateChanged);
+	lv2_atom_forge_pop(&m_forge, &frame);
+
+	return true;
+}
+
+
+#ifdef CONFIG_LV2_PATCH
+
 bool samplv1_lv2::patch_put ( uint32_t ndelta )
 {
 	static char s_szNull[1] = {'\0'};
@@ -589,31 +678,7 @@ bool samplv1_lv2::patch_put ( uint32_t ndelta )
 	return true;
 }
 
-
-bool samplv1_lv2::worker_work ( const void *data, uint32_t /*size*/ )
-{
-	const samplv1_lv2_worker_message *mesg
-		= (const samplv1_lv2_worker_message *) data;
-
-	if (mesg->atom.type == m_urids.gen1_update)
-		return true;
-	else
-	if (mesg->atom.type == m_urids.gen1_sample) {
-		samplv1::setSampleFile(mesg->sample_path);
-		return true;
-	}
-
-	return false;
-}
-
-
-bool samplv1_lv2::worker_response ( const void */*data*/, uint32_t /*size*/ )
-{
-	// update all properties, and eventually, any observers...
-	samplv1_sched::sync_notify(this, samplv1_sched::Sample, 0);
-
-	return patch_put(m_ndelta);
-}
+#endif	// CONFIG_LV2_PATCH
 
 
 //-------------------------------------------------------------------------
