@@ -83,9 +83,14 @@ public:
 
 protected:
 
+	void updatePreset(bool bDirty);
 	void updateSample();
 
+	bool state_changed();
+
+#ifdef CONFIG_LV2_PATCH
 	bool patch_put(uint32_t ndelta);
+#endif
 
 private:
 
@@ -108,13 +113,15 @@ private:
 		LV2_URID bufsz_minBlockLength;
 		LV2_URID bufsz_maxBlockLength;
 		LV2_URID bufsz_nominalBlockLength;
+		LV2_URID state_StateChanged;
+	#ifdef CONFIG_LV2_PATCH
 		LV2_URID patch_Get;
 		LV2_URID patch_Set;
 		LV2_URID patch_Put;
 		LV2_URID patch_body;
 		LV2_URID patch_property;
 		LV2_URID patch_value;
-
+	#endif
 	} m_urids;
 
 	LV2_Atom_Forge m_forge;
