@@ -25,7 +25,7 @@
 #include <QMutex>
 #include <QWaitCondition>
 
-#include <stdint.h>
+#include <QHash>
 
 
 //-------------------------------------------------------------------------
@@ -73,7 +73,7 @@ private:
 static samplv1_sched_thread *g_sched_thread = NULL;
 static uint32_t g_sched_refcount = 0;
 
-static QList<samplv1_sched_notifier *> g_sched_notifiers;
+static QHash<samplv1 *, QList<samplv1_sched_notifier *> > g_sched_notifiers;
 
 
 //-------------------------------------------------------------------------
@@ -164,9 +164,20 @@ void samplv1_sched_thread::run (void)
 //
 
 // ctor.
-samplv1_sched::samplv1_sched ( Type stype)
-	: m_stype(stype), m_sync_wait(false)
+samplv1_sched::samplv1_sched ( samplv1 *pSampl, Type stype, uint32_t nsize )
+	: m_pSampl(pSampl), m_stype(stype), m_sync_wait(false)
 {
+	m_nsize = (4 << 1);
+	while (m_nsize < nsize)
+		m_nsize <<= 1;
+	m_nmask = (m_nsize - 1);
+	m_items = new int [m_nsize];
+
+	m_iread  = 0;
+	m_iwrite = 0;
+
+	::memset(m_items, 0, m_nsize * sizeof(int));
+
 	if (++g_sched_refcount == 1 && g_sched_thread == NULL) {
 		g_sched_thread = new samplv1_sched_thread();
 		g_sched_thread->start();
@@ -177,6 +188,8 @@ samplv1_sched::samplv1_sched ( Type stype)
 // dtor (virtual).
 samplv1_sched::~samplv1_sched (void)
 {
+	delete [] m_items;
+
 	if (--g_sched_refcount == 0) {
 		if (g_sched_thread) {
 			delete g_sched_thread;
@@ -186,9 +199,22 @@ samplv1_sched::~samplv1_sched (void)
 }
 
 
-// schedule process.
-void samplv1_sched::schedule (void)
+// instance access.
+samplv1 *samplv1_sched::instance (void) const
 {
+	return m_pSampl;
+}
+
+
+// schedule process.
+void samplv1_sched::schedule ( int sid )
+{
+	const uint32_t w = (m_iwrite + 1) & m_nmask;
+	if (w != m_iread) {
+		m_items[m_iwrite] = sid;
+		m_iwrite = w;
+	}
+
 	if (g_sched_thread)
 		g_sched_thread->schedule(this);
 }
@@ -209,20 +235,31 @@ bool samplv1_sched::sync_wait (void)
 // scheduled processor.
 void samplv1_sched::sync_process (void)
 {
-	process();
+	// do whatever we must...
+	uint32_t r = m_iread;
+	while (r != m_iwrite) {
+		const int sid = m_items[r];
+		process(sid);
+		sync_notify(m_pSampl, m_stype, sid);
+		m_items[r] = 0;
+		++r &= m_nmask;
+	}
+	m_iread = r;
 
 	m_sync_wait = false;
-
-	sync_notify(m_stype);
 }
 
 
 // signal broadcast (static).
-void samplv1_sched::sync_notify ( Type stype )
+void samplv1_sched::sync_notify ( samplv1 *pSampl, Type stype, int sid )
 {
-	QListIterator<samplv1_sched_notifier *> iter(g_sched_notifiers);
-	while (iter.hasNext())
-		iter.next()->sync_notify(stype);
+	if (g_sched_notifiers.contains(pSampl)) {
+		const QList<samplv1_sched_notifier *>& list
+			= g_sched_notifiers.value(pSampl);
+		QListIterator<samplv1_sched_notifier *> iter(list);
+		while (iter.hasNext())
+			iter.next()->notify(stype, sid);
+	}
 }
 
 
@@ -231,23 +268,22 @@ void samplv1_sched::sync_notify ( Type stype )
 //
 
 // ctor.
-samplv1_sched_notifier::samplv1_sched_notifier ( QObject *parent )
-	: QObject(parent)
+samplv1_sched_notifier::samplv1_sched_notifier ( samplv1 *pSampl )
+	: m_pSampl(pSampl)
 {
-	g_sched_notifiers.append(this);
+	g_sched_notifiers[m_pSampl].append(this);
 }
 
 
 // dtor.
 samplv1_sched_notifier::~samplv1_sched_notifier (void)
 {
-	g_sched_notifiers.removeAll(this);
-}
-
-
-void samplv1_sched_notifier::sync_notify ( samplv1_sched::Type stype )
-{
-	emit notify(int(stype));
+	if (g_sched_notifiers.contains(m_pSampl)) {
+		QList<samplv1_sched_notifier *>& list = g_sched_notifiers[m_pSampl];
+		list.removeAll(this);
+		if (list.isEmpty())
+			g_sched_notifiers.remove(m_pSampl);
+	}
 }
 
 
