@@ -1019,11 +1019,10 @@ void samplv1widget::updateSampleLoop ( samplv1_sample *pSample, bool bDirty )
 {
 	if (pSample) {
 		const bool bLoop = pSample->isLoop();
-		m_ui.Gen1Sample->setLoop(bLoop);
-		m_ui.Gen1LoopRangeFrame->setEnabled(bLoop);
 		const uint32_t iLoopStart = pSample->loopStart();
 		const uint32_t iLoopEnd = pSample->loopEnd();
 		const uint32_t nframes = pSample->length();
+		m_ui.Gen1LoopRangeFrame->setEnabled(bLoop);
 		m_ui.Gen1LoopStartSpinBox->setMinimum(0);
 		m_ui.Gen1LoopStartSpinBox->setMaximum(
 		    iLoopEnd > 0 ? iLoopEnd : 0);
@@ -1032,13 +1031,15 @@ void samplv1widget::updateSampleLoop ( samplv1_sample *pSample, bool bDirty )
 		m_ui.Gen1LoopEndSpinBox->setMaximum(nframes);
 		m_ui.Gen1LoopStartSpinBox->setValue(iLoopStart);
 		m_ui.Gen1LoopEndSpinBox->setValue(iLoopEnd);
+		m_ui.Gen1Sample->setLoopStart(iLoopStart);
+		m_ui.Gen1Sample->setLoopEnd(iLoopEnd);
+		m_ui.Gen1Sample->setLoop(bLoop);
 		if (bDirty) {
 			m_ui.StatusBar->showMessage(tr("Loop start: %1, end: %2")
 				.arg(iLoopStart).arg(iLoopEnd), 5000);
 			updateDirtyPreset(true);
 		}
 	} else {
-		m_ui.Gen1Sample->setLoop(false);
 		m_ui.Gen1LoopRangeFrame->setEnabled(false);
 		m_ui.Gen1LoopStartSpinBox->setMinimum(0);
 		m_ui.Gen1LoopStartSpinBox->setMaximum(0);
@@ -1046,6 +1047,9 @@ void samplv1widget::updateSampleLoop ( samplv1_sample *pSample, bool bDirty )
 		m_ui.Gen1LoopEndSpinBox->setMinimum(0);
 		m_ui.Gen1LoopEndSpinBox->setMaximum(0);
 		m_ui.Gen1LoopEndSpinBox->setValue(0);
+		m_ui.Gen1Sample->setLoopStart(0);
+		m_ui.Gen1Sample->setLoopEnd(0);
+		m_ui.Gen1Sample->setLoop(false);
 	}
 }
 
@@ -1201,8 +1205,8 @@ void samplv1widget::helpAbout (void)
 	QString sText = "<p>\n";
 	sText += "<b>" SAMPLV1_TITLE "</b> - " + tr(SAMPLV1_SUBTITLE) + "<br />\n";
 	sText += "<br />\n";
-	sText += tr("Version") + ": <b>" SAMPLV1_VERSION "</b><br />\n";
-	sText += "<small>" + tr("Build") + ": " __DATE__ " " __TIME__ "</small><br />\n";
+	sText += tr("Version") + ": <b>" CONFIG_BUILD_VERSION "</b><br />\n";
+	sText += "<small>" + tr("Build") + ": " CONFIG_BUILD_DATE "</small><br />\n";
 	QStringListIterator iter(list);
 	while (iter.hasNext()) {
 		sText += "<small><font color=\"red\">";
@@ -1234,6 +1238,10 @@ void samplv1widget::helpAboutQt (void)
 // Dirty flag (overridable virtual) methods.
 void samplv1widget::updateDirtyPreset ( bool bDirtyPreset )
 {
+	samplv1_ui *pSamplUi = ui_instance();
+	if (pSamplUi)
+		pSamplUi->updatePreset(bDirtyPreset);
+
 	m_ui.StatusBar->setModified(bDirtyPreset);
 	m_ui.Preset->setDirtyPreset(bDirtyPreset);
 }
