@@ -1,7 +1,7 @@
 // samplv1widget.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2016, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -110,9 +110,6 @@ protected slots:
 	void loopStartChanged();
 	void loopEndChanged();
 
-	// Delay BPM change.
-	void bpmSyncChanged();
-
 	// Notification updater.
 	void updateSchedNotify(int stype, int sid);
 
