@@ -51,7 +51,10 @@ samplv1widget_sample::samplv1widget_sample (
 {
 	QFrame::setMouseTracking(true);
 	QFrame::setFocusPolicy(Qt::ClickFocus);
+
 	QFrame::setMinimumSize(QSize(480, 80));
+	QFrame::setSizePolicy(
+		QSizePolicy::Preferred, QSizePolicy::MinimumExpanding);
 
 	QFrame::setAcceptDrops(true);
 
@@ -61,6 +64,9 @@ samplv1widget_sample::samplv1widget_sample (
 	m_bLoop = false;
 	m_iLoopStart = m_iLoopEnd = 0;
 
+	m_dragCursor  = DragNone;
+	m_pDragSample = NULL;
+
 	resetDragState();
 }
 
@@ -68,7 +74,7 @@ samplv1widget_sample::samplv1widget_sample (
 // Destructor.
 samplv1widget_sample::~samplv1widget_sample (void)
 {
-	setSample(0);
+	setSample(NULL);
 }
 
 
@@ -86,7 +92,9 @@ void samplv1widget_sample::setSample ( samplv1_sample *pSample )
 	m_pSample = pSample;
 
 //	m_bLoop = false;
-	m_iLoopStart = m_iLoopEnd = 0;
+//	m_iLoopStart = m_iLoopEnd = 0;
+
+	m_pDragSample = NULL;
 
 	if (m_pSample)
 		m_iChannels = m_pSample->channels();
@@ -213,7 +221,7 @@ int samplv1widget_sample::safeX ( int x ) const
 // Widget resize handler.
 void samplv1widget_sample::resizeEvent ( QResizeEvent * )
 {
-//	setSample(m_pSample);	-- reset polygon...
+	setSample(m_pSample);	// reset polygon...
 }
 
 
@@ -334,7 +342,8 @@ void samplv1widget_sample::mouseMoveEvent ( QMouseEvent *pMouseEvent )
 				QFrame::setCursor(QCursor(Qt::SizeHorCursor));
 			} else if (m_pSample && m_pSample->filename()) {
 				QList<QUrl> urls;
-				urls.append(QUrl::fromLocalFile(m_pSample->filename()));
+				m_pDragSample = m_pSample;
+				urls.append(QUrl::fromLocalFile(m_pDragSample->filename()));
 				QMimeData *pMimeData = new QMimeData();
 				pMimeData->setUrls(urls);;
 				QDrag *pDrag = new QDrag(this);
@@ -395,6 +404,7 @@ void samplv1widget_sample::mouseReleaseEvent ( QMouseEvent *pMouseEvent )
 		break;
 	}
 
+	m_pDragSample = NULL;
 	resetDragState();
 }
 
@@ -410,6 +420,7 @@ void samplv1widget_sample::keyPressEvent ( QKeyEvent *pKeyEvent )
 {
 	switch (pKeyEvent->key()) {
 	case Qt::Key_Escape:
+		m_pDragSample = NULL;
 		resetDragState();
 		update();
 		break;
@@ -423,14 +434,20 @@ void samplv1widget_sample::keyPressEvent ( QKeyEvent *pKeyEvent )
 // Drag-n-drop (more of the later) support.
 void samplv1widget_sample::dragEnterEvent ( QDragEnterEvent *pDragEnterEvent )
 {
-	if (pDragEnterEvent->source() != this
-		&& pDragEnterEvent->mimeData()->hasUrls())
+	QFrame::dragEnterEvent(pDragEnterEvent);
+
+	if (m_pDragSample && m_pDragSample == sample())
+		return;
+
+	if (pDragEnterEvent->mimeData()->hasUrls())
 		pDragEnterEvent->acceptProposedAction();
 }
 
 
 void samplv1widget_sample::dropEvent ( QDropEvent *pDropEvent )
 {
+	QFrame::dropEvent(pDropEvent);
+
 	const QMimeData *pMimeData = pDropEvent->mimeData();
 	if (pMimeData->hasUrls()) {
 		const QString& sFilename
@@ -622,4 +639,11 @@ void samplv1widget_sample::updateToolTip (void)
 }
 
 
+// Default size hint.
+QSize samplv1widget_sample::sizeHint (void) const
+{
+	return QSize(480, 80);
+}
+
+
 // end of samplv1widget_sample.cpp
